## ![](assets/images/icon25x25.png) TVM - TV Manager

[![Build Status](https://travis-ci.org/davidvuong/tvm.svg?branch=master)](https://travis-ci.org/davidvuong/tvm)

TVM is a command line tool that helps you manage your TV shows. It's currently in early development however you can try it out at your own risk. Feel free to create an issue if you find any bugs or require additional features.

## Usage

```
tvm.py

usage:
    tvm.py generate <path> [--append --force]
    tvm.py doctor [--repository --records]
    tvm.py play (<title>... [--no-open --info --random]|(--undo|--random))
    tvm.py info [<title>... [--more]]
    tvm.py ls [[<title>... [--expand]]|[--filter=<type>]]
    tvm.py check [[--sleep=<n> --without-cache --untracked]|--download]

commands:
    generate         generates records to be added in shows_added with <path>.
    play             plays the next episode in the given tv show <title>.
    doctor           checks for syntax and semantic errors in the recorded files.
    info             shows basic information about the given tv show <title>.
    ls               lists all tv shows recorded.
    check            checks for new tv shows to download.

generate:
    --append         appends stdout to records.
    --force          pre-tracked records aren't generated, force generates them.

doctor:
    --records        checks if physical files exists in the records.
    --repository     checks if entries in record have a physical counterpart.

play:
    --no-open        records but doesn't open the episode.
    --info           shows basic statistical information.
    --random         randomly selects a show to play.
    --undo           undo the most previously played episode.

info:
    --more           shows additional information from online sources.

ls:
    --expand         completed and pending seasons aren't collapsed.
    --filter=<type>  filters the result based on the filter type.
                        new: filters out shows/episodes without pending episodes.
                        recorded: filters out shows that have not been viewed.
                        nrecorded: opposite of recorded.

check:
    --download       downloads all queued shows as well as checks for new updates.
    --sleep=<n>      sleeps n seconds before performing the check [default: 0].
    --without-cache  checks but does not store results in cache.
    --untracked      shows untracked episodes that can be downloaded.

arguments:
    <path>           directory containing tv shows.
    <title>          title of the tv show.

options:
    -h --help        shows this.
    -v --version     shows version.
>>
```

## Getting Started

1. Installing via `setup.py`:

        git clone git@github.com:davidvuong/tvm.git
        cd tvm
        python setup.py install --user

    `--user` is needed to install to `~/Library/Python/2.7/lib/python/site-packages/`. If you're getting the following error when running `tvm`:

        >> tvm
        command not found: tvm

    then you'll have to export your local Python `bin/` directory. Put this at the bottom of your `.profile`.

        export PATH=$PATH:~/Library/Python/2.7/bin

2. Installing via `pip`:

    *comming soon...*

## Developer

1. First, download and setup a virtual environment.

        git clone git@github.com:davidvuong/tvm.git
        mkvirtualenv tvm
        cd tvm

2. Next, you need to install the package dependencies.

        pip install -r requirements.txt
        python setup.py develop

    If you're having issues compiling, due to this error (Mac specific):

        clang: error: unknown argument: '-mno-fused-madd' [-Wunused-command-line-argument-hard-error-in-future]
        clang: note: this will be a hard error (cannot be downgraded to a warning) in the future
        error: command 'cc' failed with exit status 1

    You can temporarily fix it by performing the following export:

        export ARCHFLAGS="-Wno-error=unused-command-line-argument-hard-error-in-future"

        pip install -r requirements.txt
        python setup.py develop

3. Once everything has successfully install, you can test and run tvm to see if it works.

        fab test
        tvm -h

    If tests pass and no errors pop up, you're all good to go.
