#!/usr/bin/env python
# -*- coding: utf-8 -*-
from tvm.commands import base
from tvm.shared.io import err, warn, info, ok
from tvm.shared.io import print_matched_status
from tvm.helpers.info import InfoHelper


class InfoCommand(base.BaseCommand):
    def __init__(self, **arguments):
        super(self.__class__, self).__init__(**dict(arguments, **{'_ignore_errors': True}))

        self.helper = InfoHelper(self.config, self.collection)
        self._extact_args(arguments)
        self._exec()

    def _extact_args(self, arguments):
        # Join by '_' and not ' ' because internally, words are '_' delimited.
        self._search_query = '_'.join(arguments.get('<title>', []))
        self._more = arguments.get('--more', False)

    def _exec(self):
        if not self._search_query:
            return self.helper.gather_and_print_show_statistics()

        matched = self.collection.find_matching_titles(self._search_query)
        print_matched_status(matched)

        # As of now, --more can only be defined if <title>... is present.
        self.helper.gather_and_print_show_statistics(matched, self._more)
